@@ -17,7 +17,7 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: filetypes.c 672 2006-08-05 12:25:49Z ntrel $
+ * $Id: filetypes.c 848 2006-09-29 07:22:46Z eht16 $
  */
 
 
@@ -58,7 +58,10 @@ enum
 	FILETYPE_UID_TCL,		// 19
 	FILETYPE_UID_ALL,		// 20
 	FILETYPE_UID_D,			// 21
-	//FILETYPE_UID_HTML,	// 22
+	FILETYPE_UID_FORTRAN,	// 22
+	FILETYPE_UID_DIFF,		// 23
+	FILETYPE_UID_FERITE,	// 24
+	FILETYPE_UID_HTML		// 25
 };
 
 
@@ -96,7 +99,10 @@ filetype *filetypes_get_from_uid(gint uid)
 		case FILETYPE_UID_TCL:		return filetypes[GEANY_FILETYPES_TCL];
 		case FILETYPE_UID_ALL:		return filetypes[GEANY_FILETYPES_ALL];
 		case FILETYPE_UID_D:		return filetypes[GEANY_FILETYPES_D];
-		//case FILETYPE_UID_HTML:	return filetypes[GEANY_FILETYPES_HTML];
+		case FILETYPE_UID_FORTRAN:	return filetypes[GEANY_FILETYPES_FORTRAN];
+		case FILETYPE_UID_DIFF:		return filetypes[GEANY_FILETYPES_DIFF];
+		case FILETYPE_UID_FERITE:	return filetypes[GEANY_FILETYPES_FERITE];
+		case FILETYPE_UID_HTML:		return filetypes[GEANY_FILETYPES_HTML];
 		default: 					return NULL;
 	}
 }
@@ -128,7 +134,6 @@ void filetypes_init_types(void)
 	filetypes[GEANY_FILETYPES_C]->style_func_ptr = styleset_c;
 	filetypes_init_build_programs(filetypes[GEANY_FILETYPES_C]);
 	filetypes_create_menu_item(filetype_menu, filetypes[GEANY_FILETYPES_C]->title, filetypes[GEANY_FILETYPES_C]);
-	filetypes_create_newmenu_item(template_menu, filetypes[GEANY_FILETYPES_C]->title, filetypes[GEANY_FILETYPES_C]);
 
 #define CPP
 	filetypes[GEANY_FILETYPES_CPP] = g_new0(filetype, 1);
@@ -157,7 +162,6 @@ void filetypes_init_types(void)
 	filetypes[GEANY_FILETYPES_CPP]->comment_close = NULL;
 	filetypes_init_build_programs(filetypes[GEANY_FILETYPES_CPP]);
 	filetypes_create_menu_item(filetype_menu, filetypes[GEANY_FILETYPES_CPP]->title, filetypes[GEANY_FILETYPES_CPP]);
-	filetypes_create_newmenu_item(template_menu, filetypes[GEANY_FILETYPES_CPP]->title, filetypes[GEANY_FILETYPES_CPP]);
 
 #define D
 	filetypes[GEANY_FILETYPES_D] = g_new0(filetype, 1);
@@ -178,7 +182,6 @@ void filetypes_init_types(void)
 	filetypes[GEANY_FILETYPES_D]->style_func_ptr = styleset_d;
 	filetypes_init_build_programs(filetypes[GEANY_FILETYPES_D]);
 	filetypes_create_menu_item(filetype_menu, filetypes[GEANY_FILETYPES_D]->title, filetypes[GEANY_FILETYPES_D]);
-	filetypes_create_newmenu_item(template_menu, filetypes[GEANY_FILETYPES_D]->title, filetypes[GEANY_FILETYPES_D]);
 
 #define JAVA
 	filetypes[GEANY_FILETYPES_JAVA] = g_new0(filetype, 1);
@@ -198,7 +201,6 @@ void filetypes_init_types(void)
 	filetypes[GEANY_FILETYPES_JAVA]->style_func_ptr = styleset_java;
 	filetypes_init_build_programs(filetypes[GEANY_FILETYPES_JAVA]);
 	filetypes_create_menu_item(filetype_menu, filetypes[GEANY_FILETYPES_JAVA]->title, filetypes[GEANY_FILETYPES_JAVA]);
-	filetypes_create_newmenu_item(template_menu, filetypes[GEANY_FILETYPES_JAVA]->title, filetypes[GEANY_FILETYPES_JAVA]);
 
 #define PAS // to avoid warnings when building under Windows, the symbol PASCAL is there defined
 	filetypes[GEANY_FILETYPES_PASCAL] = g_new0(filetype, 1);
@@ -222,7 +224,6 @@ void filetypes_init_types(void)
 	filetypes[GEANY_FILETYPES_PASCAL]->comment_close = g_strdup("}");
 	filetypes_init_build_programs(filetypes[GEANY_FILETYPES_PASCAL]);
 	filetypes_create_menu_item(filetype_menu, filetypes[GEANY_FILETYPES_PASCAL]->title, filetypes[GEANY_FILETYPES_PASCAL]);
-	filetypes_create_newmenu_item(template_menu, filetypes[GEANY_FILETYPES_PASCAL]->title, filetypes[GEANY_FILETYPES_PASCAL]);
 
 #define ASM
 	filetypes[GEANY_FILETYPES_ASM] = g_new0(filetype, 1);
@@ -243,6 +244,30 @@ void filetypes_init_types(void)
 	filetypes_init_build_programs(filetypes[GEANY_FILETYPES_ASM]);
 	filetypes_create_menu_item(filetype_menu, filetypes[GEANY_FILETYPES_ASM]->title, filetypes[GEANY_FILETYPES_ASM]);
 
+#define FORTRAN
+	filetypes[GEANY_FILETYPES_FORTRAN] = g_new0(filetype, 1);
+	filetypes[GEANY_FILETYPES_FORTRAN]->id = GEANY_FILETYPES_FORTRAN;
+	filetypes[GEANY_FILETYPES_FORTRAN]->uid = FILETYPE_UID_FORTRAN;
+	filetypes[GEANY_FILETYPES_FORTRAN]->item = NULL;
+	filetypes[GEANY_FILETYPES_FORTRAN]->lang = 18;
+	filetypes[GEANY_FILETYPES_FORTRAN]->name = g_strdup("Fortran");
+	filetypes[GEANY_FILETYPES_FORTRAN]->has_tags = TRUE;
+	filetypes[GEANY_FILETYPES_FORTRAN]->title = g_strdup(_("Fortran source file (F77)"));
+	filetypes[GEANY_FILETYPES_FORTRAN]->extension = g_strdup("f");
+	filetypes[GEANY_FILETYPES_FORTRAN]->pattern = g_new0(gchar*, 7);
+	filetypes[GEANY_FILETYPES_FORTRAN]->pattern[0] = g_strdup("*.f");
+	filetypes[GEANY_FILETYPES_FORTRAN]->pattern[1] = g_strdup("*.for");
+	filetypes[GEANY_FILETYPES_FORTRAN]->pattern[2] = g_strdup("*.ftn");
+	filetypes[GEANY_FILETYPES_FORTRAN]->pattern[3] = g_strdup("*.f77");
+	filetypes[GEANY_FILETYPES_FORTRAN]->pattern[4] = g_strdup("*.f90");
+	filetypes[GEANY_FILETYPES_FORTRAN]->pattern[5] = g_strdup("*.f95");
+	filetypes[GEANY_FILETYPES_FORTRAN]->pattern[6] = NULL;
+	filetypes[GEANY_FILETYPES_FORTRAN]->style_func_ptr = styleset_fortran;
+	filetypes[GEANY_FILETYPES_FORTRAN]->comment_open = g_strdup("c");
+	filetypes[GEANY_FILETYPES_FORTRAN]->comment_close = NULL;
+	filetypes_init_build_programs(filetypes[GEANY_FILETYPES_FORTRAN]);
+	filetypes_create_menu_item(filetype_menu, filetypes[GEANY_FILETYPES_FORTRAN]->title, filetypes[GEANY_FILETYPES_FORTRAN]);
+
 #define CAML
 	filetypes[GEANY_FILETYPES_CAML] = g_new0(filetype, 1);
 	filetypes[GEANY_FILETYPES_CAML]->id = GEANY_FILETYPES_CAML;
@@ -273,11 +298,12 @@ void filetypes_init_types(void)
 	filetypes[GEANY_FILETYPES_PERL]->has_tags = TRUE;
 	filetypes[GEANY_FILETYPES_PERL]->title = g_strdup(_("Perl source file"));
 	filetypes[GEANY_FILETYPES_PERL]->extension = g_strdup("perl");
-	filetypes[GEANY_FILETYPES_PERL]->pattern = g_new0(gchar*, 4);
+	filetypes[GEANY_FILETYPES_PERL]->pattern = g_new0(gchar*, 5);
 	filetypes[GEANY_FILETYPES_PERL]->pattern[0] = g_strdup("*.pl");
 	filetypes[GEANY_FILETYPES_PERL]->pattern[1] = g_strdup("*.perl");
 	filetypes[GEANY_FILETYPES_PERL]->pattern[2] = g_strdup("*.pm");
-	filetypes[GEANY_FILETYPES_PERL]->pattern[3] = NULL;
+	filetypes[GEANY_FILETYPES_PERL]->pattern[3] = g_strdup("*.agi");
+	filetypes[GEANY_FILETYPES_PERL]->pattern[4] = NULL;
 	filetypes[GEANY_FILETYPES_PERL]->comment_open = g_strdup("#");
 	filetypes[GEANY_FILETYPES_PERL]->comment_close = NULL;
 	filetypes[GEANY_FILETYPES_PERL]->style_func_ptr = styleset_perl;
@@ -292,22 +318,20 @@ void filetypes_init_types(void)
 	filetypes[GEANY_FILETYPES_PHP]->lang = 6;
 	filetypes[GEANY_FILETYPES_PHP]->name = g_strdup("PHP");
 	filetypes[GEANY_FILETYPES_PHP]->has_tags = TRUE;
-	filetypes[GEANY_FILETYPES_PHP]->title = g_strdup(_("PHP / HTML source file"));
+	filetypes[GEANY_FILETYPES_PHP]->title = g_strdup(_("PHP source file"));
 	filetypes[GEANY_FILETYPES_PHP]->extension = g_strdup("php");
-	filetypes[GEANY_FILETYPES_PHP]->pattern = g_new0(gchar*, 7);
+	filetypes[GEANY_FILETYPES_PHP]->pattern = g_new0(gchar*, 6);
 	filetypes[GEANY_FILETYPES_PHP]->pattern[0] = g_strdup("*.php");
 	filetypes[GEANY_FILETYPES_PHP]->pattern[1] = g_strdup("*.php3");
 	filetypes[GEANY_FILETYPES_PHP]->pattern[2] = g_strdup("*.php4");
 	filetypes[GEANY_FILETYPES_PHP]->pattern[3] = g_strdup("*.php5");
-	filetypes[GEANY_FILETYPES_PHP]->pattern[4] = g_strdup("*.html");
-	filetypes[GEANY_FILETYPES_PHP]->pattern[5] = g_strdup("*.htm");
-	filetypes[GEANY_FILETYPES_PHP]->pattern[6] = NULL;
+	filetypes[GEANY_FILETYPES_PHP]->pattern[4] = g_strdup("*.phtml");
+	filetypes[GEANY_FILETYPES_PHP]->pattern[5] = NULL;
 	filetypes[GEANY_FILETYPES_PHP]->style_func_ptr = styleset_php;
 	filetypes[GEANY_FILETYPES_PHP]->comment_open = g_strdup("//");
 	filetypes[GEANY_FILETYPES_PHP]->comment_close = NULL;
 	filetypes_init_build_programs(filetypes[GEANY_FILETYPES_PHP]);
 	filetypes_create_menu_item(filetype_menu, filetypes[GEANY_FILETYPES_PHP]->title, filetypes[GEANY_FILETYPES_PHP]);
-	filetypes_create_newmenu_item(template_menu, filetypes[GEANY_FILETYPES_PHP]->title, filetypes[GEANY_FILETYPES_PHP]);
 
 #define PYTHON
 	filetypes[GEANY_FILETYPES_PYTHON] = g_new0(filetype, 1);
@@ -348,7 +372,6 @@ void filetypes_init_types(void)
 	filetypes[GEANY_FILETYPES_RUBY]->comment_close = NULL;
 	filetypes_init_build_programs(filetypes[GEANY_FILETYPES_RUBY]);
 	filetypes_create_menu_item(filetype_menu, filetypes[GEANY_FILETYPES_RUBY]->title, filetypes[GEANY_FILETYPES_RUBY]);
-	filetypes_create_newmenu_item(template_menu, filetypes[GEANY_FILETYPES_RUBY]->title, filetypes[GEANY_FILETYPES_RUBY]);
 
 #define TCL
 	filetypes[GEANY_FILETYPES_TCL] = g_new0(filetype, 1);
@@ -371,6 +394,25 @@ void filetypes_init_types(void)
 	filetypes_init_build_programs(filetypes[GEANY_FILETYPES_TCL]);
 	filetypes_create_menu_item(filetype_menu, filetypes[GEANY_FILETYPES_TCL]->title, filetypes[GEANY_FILETYPES_TCL]);
 
+#define FERITE
+	filetypes[GEANY_FILETYPES_FERITE] = g_new0(filetype, 1);
+	filetypes[GEANY_FILETYPES_FERITE]->id = GEANY_FILETYPES_FERITE;
+	filetypes[GEANY_FILETYPES_FERITE]->uid = FILETYPE_UID_FERITE;
+	filetypes[GEANY_FILETYPES_FERITE]->item = NULL;
+	filetypes[GEANY_FILETYPES_FERITE]->lang = 19;
+	filetypes[GEANY_FILETYPES_FERITE]->name = g_strdup("Ferite");
+	filetypes[GEANY_FILETYPES_FERITE]->has_tags = TRUE;
+	filetypes[GEANY_FILETYPES_FERITE]->title = g_strdup(_("Ferite source file"));
+	filetypes[GEANY_FILETYPES_FERITE]->extension = g_strdup("fe");
+	filetypes[GEANY_FILETYPES_FERITE]->pattern = g_new0(gchar*, 2);
+	filetypes[GEANY_FILETYPES_FERITE]->pattern[0] = g_strdup("*.fe");
+	filetypes[GEANY_FILETYPES_FERITE]->pattern[1] = NULL;
+	filetypes[GEANY_FILETYPES_FERITE]->style_func_ptr = styleset_ferite;
+	filetypes[GEANY_FILETYPES_FERITE]->comment_open = g_strdup("/*");
+	filetypes[GEANY_FILETYPES_FERITE]->comment_close = g_strdup("*/");
+	filetypes_init_build_programs(filetypes[GEANY_FILETYPES_FERITE]);
+	filetypes_create_menu_item(filetype_menu, filetypes[GEANY_FILETYPES_FERITE]->title, filetypes[GEANY_FILETYPES_FERITE]);
+
 #define SH
 	filetypes[GEANY_FILETYPES_SH] = g_new0(filetype, 1);
 	filetypes[GEANY_FILETYPES_SH]->id = GEANY_FILETYPES_SH;
@@ -455,6 +497,31 @@ void filetypes_init_types(void)
 	filetypes_init_build_programs(filetypes[GEANY_FILETYPES_DOCBOOK]);
 	filetypes_create_menu_item(filetype_menu, filetypes[GEANY_FILETYPES_DOCBOOK]->title, filetypes[GEANY_FILETYPES_DOCBOOK]);
 
+#define HTML
+	filetypes[GEANY_FILETYPES_HTML] = g_new0(filetype, 1);
+	filetypes[GEANY_FILETYPES_HTML]->id = GEANY_FILETYPES_HTML;
+	filetypes[GEANY_FILETYPES_HTML]->uid = FILETYPE_UID_HTML;
+	filetypes[GEANY_FILETYPES_HTML]->item = NULL;
+	filetypes[GEANY_FILETYPES_HTML]->lang = -2;
+	filetypes[GEANY_FILETYPES_HTML]->name = g_strdup("HTML");
+	filetypes[GEANY_FILETYPES_HTML]->has_tags = FALSE;
+	filetypes[GEANY_FILETYPES_HTML]->title = g_strdup(_("HTML source file"));
+	filetypes[GEANY_FILETYPES_HTML]->extension = g_strdup("html");
+	filetypes[GEANY_FILETYPES_HTML]->pattern = g_new0(gchar*, 8);
+	filetypes[GEANY_FILETYPES_HTML]->pattern[0] = g_strdup("*.htm");
+	filetypes[GEANY_FILETYPES_HTML]->pattern[1] = g_strdup("*.html");
+	filetypes[GEANY_FILETYPES_HTML]->pattern[2] = g_strdup("*.shtml");
+	filetypes[GEANY_FILETYPES_HTML]->pattern[3] = g_strdup("*.hta");
+	filetypes[GEANY_FILETYPES_HTML]->pattern[4] = g_strdup("*.htd");
+	filetypes[GEANY_FILETYPES_HTML]->pattern[5] = g_strdup("*.htt");
+	filetypes[GEANY_FILETYPES_HTML]->pattern[6] = g_strdup("*.cfm");
+	filetypes[GEANY_FILETYPES_HTML]->pattern[7] = NULL;
+	filetypes[GEANY_FILETYPES_HTML]->style_func_ptr = styleset_html;
+	filetypes[GEANY_FILETYPES_HTML]->comment_open = g_strdup("<!--");
+	filetypes[GEANY_FILETYPES_HTML]->comment_close = g_strdup("-->");
+	filetypes_init_build_programs(filetypes[GEANY_FILETYPES_HTML]);
+	filetypes_create_menu_item(filetype_menu, filetypes[GEANY_FILETYPES_HTML]->title, filetypes[GEANY_FILETYPES_HTML]);
+
 #define CSS
 	filetypes[GEANY_FILETYPES_CSS] = g_new0(filetype, 1);
 	filetypes[GEANY_FILETYPES_CSS]->id = GEANY_FILETYPES_CSS;
@@ -533,6 +600,26 @@ void filetypes_init_types(void)
 	filetypes_init_build_programs(filetypes[GEANY_FILETYPES_OMS]);
 	filetypes_create_menu_item(filetype_menu, filetypes[GEANY_FILETYPES_OMS]->title, filetypes[GEANY_FILETYPES_OMS]);
 
+#define DIFF
+	filetypes[GEANY_FILETYPES_DIFF] = g_new0(filetype, 1);
+	filetypes[GEANY_FILETYPES_DIFF]->id = GEANY_FILETYPES_DIFF;
+	filetypes[GEANY_FILETYPES_DIFF]->uid = FILETYPE_UID_DIFF;
+	filetypes[GEANY_FILETYPES_DIFF]->item = NULL;
+	filetypes[GEANY_FILETYPES_DIFF]->lang = -2;
+	filetypes[GEANY_FILETYPES_DIFF]->name = g_strdup("Diff");
+	filetypes[GEANY_FILETYPES_DIFF]->has_tags = FALSE;
+	filetypes[GEANY_FILETYPES_DIFF]->title = g_strdup(_("Diff file"));
+	filetypes[GEANY_FILETYPES_DIFF]->extension = g_strdup("diff");
+	filetypes[GEANY_FILETYPES_DIFF]->pattern = g_new0(gchar*, 3);
+	filetypes[GEANY_FILETYPES_DIFF]->pattern[0] = g_strdup("*.diff");
+	filetypes[GEANY_FILETYPES_DIFF]->pattern[1] = g_strdup("*.patch");
+	filetypes[GEANY_FILETYPES_DIFF]->pattern[2] = NULL;
+	filetypes[GEANY_FILETYPES_DIFF]->style_func_ptr = styleset_diff;
+	filetypes[GEANY_FILETYPES_DIFF]->comment_open = g_strdup("#");
+	filetypes[GEANY_FILETYPES_DIFF]->comment_close = NULL;
+	filetypes_init_build_programs(filetypes[GEANY_FILETYPES_DIFF]);
+	filetypes_create_menu_item(filetype_menu, filetypes[GEANY_FILETYPES_DIFF]->title, filetypes[GEANY_FILETYPES_DIFF]);
+
 #define CONF
 	filetypes[GEANY_FILETYPES_CONF] = g_new0(filetype, 1);
 	filetypes[GEANY_FILETYPES_CONF]->id = GEANY_FILETYPES_CONF;
@@ -574,6 +661,25 @@ void filetypes_init_types(void)
 	filetypes[GEANY_FILETYPES_ALL]->comment_close = NULL;
 	filetypes_init_build_programs(filetypes[GEANY_FILETYPES_ALL]);
 	filetypes_create_menu_item(filetype_menu, _("None"), filetypes[GEANY_FILETYPES_ALL]);
+
+	// now add the items for the new file menu
+	filetypes_create_newmenu_item(template_menu, filetypes[GEANY_FILETYPES_C]->title,
+																filetypes[GEANY_FILETYPES_C]);
+	filetypes_create_newmenu_item(template_menu, filetypes[GEANY_FILETYPES_CPP]->title,
+																filetypes[GEANY_FILETYPES_CPP]);
+	filetypes_create_newmenu_item(template_menu, filetypes[GEANY_FILETYPES_D]->title,
+																filetypes[GEANY_FILETYPES_D]);
+	filetypes_create_newmenu_item(template_menu, filetypes[GEANY_FILETYPES_JAVA]->title,
+																filetypes[GEANY_FILETYPES_JAVA]);
+	filetypes_create_newmenu_item(template_menu, filetypes[GEANY_FILETYPES_PASCAL]->title,
+																filetypes[GEANY_FILETYPES_PASCAL]);
+	filetypes_create_newmenu_item(template_menu, filetypes[GEANY_FILETYPES_RUBY]->title,
+																filetypes[GEANY_FILETYPES_RUBY]);
+	filetypes_create_newmenu_item(template_menu, filetypes[GEANY_FILETYPES_PHP]->title,
+																filetypes[GEANY_FILETYPES_PHP]);
+	filetypes_create_newmenu_item(template_menu, filetypes[GEANY_FILETYPES_HTML]->title,
+																filetypes[GEANY_FILETYPES_HTML]);
+
 }
 
 
@@ -727,6 +833,8 @@ gchar *filetypes_get_template(filetype *ft)
 			return templates_get_template_generic(GEANY_TEMPLATE_FILETYPE_RUBY); break;
 		case GEANY_FILETYPES_D:
 			return templates_get_template_generic(GEANY_TEMPLATE_FILETYPE_D); break;
+		case GEANY_FILETYPES_HTML:
+			return templates_get_template_generic(GEANY_TEMPLATE_FILETYPE_HTML); break;
 		default: return NULL;
 	}
 }
@@ -801,3 +909,24 @@ void filetypes_get_config(GKeyFile *config, GKeyFile *configh, gint ft)
 		filetypes[ft]->menu_items->can_exec = TRUE;
 	}
 }
+
+
+GtkFileFilter *filetypes_create_file_filter(filetype *ft)
+{
+	GtkFileFilter *new_filter;
+	gint i;
+
+	new_filter = gtk_file_filter_new();
+	gtk_file_filter_set_name(new_filter, ft->title);
+
+	// (GEANY_FILETYPES_MAX_PATTERNS - 1) because the last field in pattern is NULL
+	//for (i = 0; i < (GEANY_MAX_PATTERNS - 1) && ft->pattern[i]; i++)
+	for (i = 0; ft->pattern[i]; i++)
+	{
+		gtk_file_filter_add_pattern(new_filter, ft->pattern[i]);
+	}
+
+	return new_filter;
+}
+
+
