@@ -17,13 +17,20 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: highlighting.h 544 2006-07-09 14:41:53Z eht16 $
+ * $Id: highlighting.h 779 2006-09-01 17:07:49Z eht16 $
  */
 
 
 #ifndef GEANY_HIGHLIGHTING_H
 #define GEANY_HIGHLIGHTING_H 1
 
+#ifndef PLAT_GTK
+#   define PLAT_GTK 1	// needed for ScintillaWidget.h
+#endif
+
+#include "Scintilla.h"
+#include "ScintillaWidget.h"
+
 
 typedef struct
 {
@@ -47,6 +54,8 @@ void styleset_latex(ScintillaObject *sci);
 
 void styleset_php(ScintillaObject *sci);
 
+void styleset_html(ScintillaObject *sci);
+
 void styleset_java(ScintillaObject *sci);
 
 void styleset_pascal(ScintillaObject *sci);
@@ -83,4 +92,10 @@ void styleset_tcl(ScintillaObject *sci);
 
 void styleset_d(ScintillaObject *sci);
 
+void styleset_fortran(ScintillaObject *sci);
+
+void styleset_diff(ScintillaObject *sci);
+
+void styleset_ferite(ScintillaObject *sci);
+
 #endif
