@@ -17,7 +17,7 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: utils.h 680 2006-08-07 14:53:58Z ntrel $
+ * $Id: utils.h 794 2006-09-06 17:31:53Z eht16 $
  */
 
 
@@ -27,28 +27,6 @@
 
 void utils_start_browser(const gchar *uri);
 
-/* allow_override is TRUE if text can be ignored when another message has been set
- * that didn't use allow_override and has not timed out. */
-void utils_set_statusbar(const gchar *text, gboolean allow_override);
-
-void utils_update_statusbar(gint idx, gint pos);
-
-void utils_set_buttons_state(gboolean enable);
-
-void utils_update_popup_reundo_items(gint idx);
-
-void utils_update_popup_copy_items(gint idx);
-
-void utils_update_insert_include_item(gint idx, gint item);
-
-void utils_update_menu_copy_items(gint idx);
-
-void utils_update_popup_goto_items(gboolean enable);
-
-void utils_save_buttons_toggle(gboolean enable);
-
-void utils_close_buttons_toggle(void);
-
 /* taken from anjuta, to determine the EOL mode of the file */
 gint utils_get_line_endings(gchar* buffer, glong size);
 
@@ -56,11 +34,6 @@ gboolean utils_isbrace(gchar c);
 
 gboolean utils_is_opening_brace(gchar c);
 
-/* This sets the window title according to the current filename. */
-void utils_set_window_title(gint index);
-
-void utils_set_editor_font(const gchar *font_name);
-
 const GList *utils_get_tag_list(gint idx, guint tag_types);
 
 gint utils_get_local_tag(gint idx, const gchar *qual_name);
@@ -69,31 +42,14 @@ gboolean utils_goto_file_line(const gchar *file, gboolean is_tm_filename, gint l
 
 gboolean utils_goto_line(gint idx, gint line);
 
-GdkPixbuf *utils_new_pixbuf_from_inline(gint img, gboolean small_img);
-
-GtkWidget *utils_new_image_from_inline(gint img, gboolean small_img);
-
 gint utils_write_file(const gchar *filename, const gchar *text);
 
-void utils_show_indention_guides(void);
-
-void utils_show_white_space(void);
-
-void utils_show_linenumber_margin(void);
-
-void utils_show_markers_margin(void);
-
-void utils_show_line_endings(void);
-
-void utils_set_fullscreen(void);
-
-GtkFileFilter *utils_create_file_filter(filetype *ft);
-
-void utils_update_tag_list(gint idx, gboolean update);
-
 gchar *utils_convert_to_utf8(const gchar *buffer, gsize size, gchar **used_encoding);
 
-gchar *utils_convert_to_utf8_from_charset(const gchar *buffer, gsize size, const gchar *charset);
+/* Converts a string from the given charset to UTF-8.
+ * If fast is set, no further checks are performed. */
+gchar *utils_convert_to_utf8_from_charset(const gchar *buffer, gsize size, const gchar *charset,
+										  gboolean fast);
 
 /**
  * (stolen from anjuta and modified)
@@ -107,8 +63,6 @@ gboolean utils_check_disk_status(gint idx);
 //gchar *utils_get_current_tag(gint idx, gint direction);
 gint utils_get_current_function(gint idx, const gchar **tagname);
 
-void utils_find_current_word(ScintillaObject *sci, gint pos, gchar *word, size_t wordlen);
-
 /* returns the end-of-line character(s) length of the specified editor */
 gint utils_get_eol_char_len(gint idx);
 
@@ -126,10 +80,6 @@ gboolean utils_is_absolute_path(const gchar *path);
 
 gdouble utils_scale_round(gdouble val, gdouble factor);
 
-void utils_widget_show_hide(GtkWidget *widget, gboolean show);
-
-void utils_build_show_hide(gint);
-
 /* (taken from libexo from os-cillation)
  * NULL-safe string comparison. Returns TRUE if both a and b are
  * NULL or if a and b refer to valid strings which are equal.
@@ -141,15 +91,9 @@ gboolean utils_strcmp(const gchar *a, const gchar *b);
 gchar *utils_remove_ext_from_filename(const gchar *filename);
 
 
-/* Finds a corresponding matching brace to the given pos
- * (this is taken from Scintilla Editor.cxx,
- * fit to work with sci_cb_close_block) */
-gint utils_brace_match(ScintillaObject *sci, gint pos);
-
-
 gchar utils_brace_opposite(gchar ch);
 
-gchar *utils_get_hostname(void);
+gchar *utils_get_hostname();
 
 gint utils_make_settings_dir(const gchar *dir, const gchar *data_dir, const gchar *doc_dir);
 
@@ -157,20 +101,12 @@ gchar *utils_str_replace(gchar *haystack, const gchar *needle, const gchar *repl
 
 gint utils_strpos(const gchar* haystack, const gchar * needle);
 
-gchar *utils_get_date_time(void);
+gchar *utils_get_date_time();
 
-gchar *utils_get_date(void);
-
-void utils_create_insert_menu_items(void);
+gchar *utils_get_date();
 
 gchar *utils_get_initials(gchar *name);
 
-void utils_update_toolbar_icons(GtkIconSize size);
-
-void utils_add_recent_file(const gchar *filename);
-
-void utils_recent_file_loaded(const gchar *filename);
-
 gboolean utils_get_setting_boolean(GKeyFile *config, const gchar *section, const gchar *key, const gboolean default_value);
 
 gint utils_get_setting_integer(GKeyFile *config, const gchar *section, const gchar *key, const gint default_value);
@@ -185,29 +121,18 @@ gint utils_compare_symbol(const GeanySymbol *a, const GeanySymbol *b);
 
 gchar *utils_get_hex_from_color(GdkColor *color);
 
-void utils_treeviews_showhide(gboolean force);
-
 gchar *utils_get_current_file_dir();
 
-void utils_beep(void);
+void utils_beep();
 
 gchar *utils_make_human_readable_str(unsigned long long size, unsigned long block_size,
 									 unsigned long display_unit);
 
-void utils_update_fold_items(void);
-
 /* utils_strtod() converts a string containing a hex colour ("0x00ff00") into an integer.
  * Basically, it is the same as strtod() would do, but it does not understand hex colour values,
  * before ANSI-C99. With with_route set, it takes strings of the format "#00ff00". */
 gint utils_strtod(const gchar *source, gchar **end, gboolean with_route);
 
-/* try to parse the file and line number where the error occured described in line
- * and when something useful is found, it stores the line number in *line and the
- * relevant file with the error in filename.
- * *line will be -1 if no error was found in string.
- * filename must be freed unless it is NULL. */
-void utils_parse_compiler_error_line(const gchar *string, gchar **filename, gint *line);
-
 // returned string must be freed.
 gchar *utils_get_current_time_string();
 
@@ -215,8 +140,6 @@ TMTag *utils_find_tm_tag(const GPtrArray *tags, const gchar *tag_name);
 
 GIOChannel *utils_set_up_io_channel(gint fd, GIOCondition cond, GIOFunc func, gpointer data);
 
-void utils_update_toolbar_items(void);
-
 gchar **utils_read_file_in_array(const gchar *filename);
 
 /* Contributed by Stefan Oltmanns, thanks.
@@ -227,10 +150,14 @@ gchar *utils_scan_unicode_bom(const gchar *string);
 
 gboolean utils_is_unicode_charset(const gchar *string);
 
-void utils_document_show_hide(gint idx);
-
 /* Wraps a string in place, replacing a space with a newline character.
  * wrapstart is the minimum position to start wrapping or -1 for default */
 gboolean utils_wrap_string(gchar *string, gint wrapstart);
 
+/* Simple wrapper for g_locale_from_utf8; returns a copy of utf8_text on failure. */
+gchar *utils_get_locale_from_utf8(const gchar *utf8_text);
+
+/* Simple wrapper for g_locale_to_utf8; returns a copy of locale_text on failure. */
+gchar *utils_get_utf8_from_locale(const gchar *locale_text);
+
 #endif
