@@ -17,7 +17,7 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: win32.c 643 2006-07-27 23:17:31Z eht16 $
+ *  $Id: win32.c 810 2006-09-11 07:41:37Z eht16 $
  */
 
 
@@ -40,6 +40,7 @@
 #include "document.h"
 #include "support.h"
 #include "utils.h"
+#include "ui_utils.h"
 #include "sciwrappers.h"
 #include "dialogs.h"
 
@@ -210,7 +211,7 @@ void win32_show_font_dialog(void)
 	{
 			gchar *editorfont = g_strdup_printf("%s %d", lf.lfFaceName,
 				(cf.iPointSize / 10));
-			utils_set_editor_font(editorfont);
+			ui_set_editor_font(editorfont);
 			g_free(editorfont);
 	}
 }
